/* GNOME DB components libary
 * Copyright (C) 2000 Rodrigo Moya
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#if !defined(__gnome_db_control_corba_h__)
#  define __gnome_db_control_corba_h__

#include <orb/orb.h>

#include <GnomeDB.h>
#include "gnome-db-control.h"

/*** Implementation stub prototypes ***/
                                                     
CORBA_char* impl_GNOME_DB_Control_getVersion (PortableServer_Servant servant,
                                              CORBA_Environment * ev);
CORBA_char* impl_GNOME_DB_Control_getAuthors (PortableServer_Servant servant,
                                              CORBA_Environment *ev);
void impl_GNOME_DB_Control_run (PortableServer_Servant servant,
                                CORBA_Environment *ev);

void impl_GNOME_DB_Control_setOwner (PortableServer_Servant servant,
				     CORBA_Environment *ev);
void impl_GNOME_DB_Control_unsetOwner (PortableServer_Servant servant,
				       CORBA_Environment *ev);

void impl_GNOME_DB_Control_doPrint (PortableServer_Servant servant,
                                    CORBA_Environment *ev);
void impl_GNOME_DB_Control_doCutClipboard (PortableServer_Servant servant,
                                           CORBA_Environment *ev);
void impl_GNOME_DB_Control_doCopyClipboard (PortableServer_Servant servant,
                                            CORBA_Environment *ev);
void impl_GNOME_DB_Control_doPasteClipboard (PortableServer_Servant servant,
                                             CORBA_Environment *ev);

#endif
